# Generated by Django 4.1.3 on 2023-02-07 07:01

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("alastria_auth", "0002_apisession_request_session_id_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="apisession",
            name="extra_info",
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="apisession",
            name="expiration_date",
            field=models.DateTimeField(
                default=datetime.datetime(
                    2023, 2, 10, 7, 1, 36, 872311, tzinfo=datetime.timezone.utc
                ),
                verbose_name="Expirate date",
            ),
        ),
        migrations.AlterField(
            model_name="requestsession",
            name="expiration_date",
            field=models.DateTimeField(
                default=datetime.datetime(
                    2023, 2, 7, 7, 6, 36, 872311, tzinfo=datetime.timezone.utc
                ),
                verbose_name="Expirate date",
            ),
        ),
    ]
