# Generated by Django 4.1.3 on 2023-02-07 09:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("alastria_auth", "0003_apisession_extra_info_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="apisession",
            name="expiration_date",
            field=models.DateTimeField(verbose_name="Expirate date"),
        ),
        migrations.AlterField(
            model_name="apisession",
            name="token",
            field=models.CharField(max_length=1255),
        ),
        migrations.AlterField(
            model_name="requestsession",
            name="expiration_date",
            field=models.DateTimeField(verbose_name="Expirate date"),
        ),
    ]
