# Generated by Django 4.1.3 on 2023-01-13 08:23

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ApiSession',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('token', models.CharField(max_length=255)),
                ('expiration_date', models.DateTimeField(default=datetime.datetime(2023, 1, 16, 8, 23, 21, 999940, tzinfo=datetime.timezone.utc), verbose_name='Expirate date')),
                ('is_active', models.BooleanField(default=True)),
            ],
        ),
        migrations.CreateModel(
            name='RequestSession',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('request_date', models.DateTimeField()),
                ('expiration_date', models.DateTimeField(default=datetime.datetime(2023, 1, 13, 8, 28, 21, 999126, tzinfo=datetime.timezone.utc), verbose_name='Expirate date')),
                ('requested_by', models.CharField(max_length=255)),
                ('qr_code', models.ImageField(upload_to='')),
                ('confirm_url', models.CharField(max_length=255)),
            ],
        ),
    ]
