# Generated by Django 4.1.3 on 2023-01-16 07:19

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('alastria_auth', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='apisession',
            name='request_session_id',
            field=models.IntegerField(default=1),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='requestsession',
            name='completed',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='apisession',
            name='expiration_date',
            field=models.DateTimeField(default=datetime.datetime(2023, 1, 19, 7, 19, 45, 895576, tzinfo=datetime.timezone.utc), verbose_name='Expirate date'),
        ),
        migrations.AlterField(
            model_name='requestsession',
            name='expiration_date',
            field=models.DateTimeField(default=datetime.datetime(2023, 1, 16, 7, 24, 45, 894997, tzinfo=datetime.timezone.utc), verbose_name='Expirate date'),
        ),
    ]
